pornlinks = [
    "https://telegra.ph/file/9bcc076fd81dfe3feb291.mp4",
    "https://telegra.ph/file/b7a1a42429a65f64e67af.mp4",
    "https://telegra.ph/file/dc3da5a3eb77ae20fa21d.mp4",
    "https://telegra.ph/file/22b89774a4ba9219d530b.mp4",
    "https://telegra.ph/file/7b15fbca08ae1e73e559c.mp4",
    "https://telegra.ph/file/a9c1dea3f34925bb60686.mp4",
    "https://telegra.ph/file/913b4e567b7f435b7f0db.mp4",
    "https://telegra.ph/file/5a5d1a919a97af2314955.mp4",
    "https://telegra.ph/file/0f8b903669600d304cbe4.mp4",
    "https://telegra.ph/file/f3816b54c9eb7617356b6.mp4",
    "https://telegra.ph/file/516dbaa03fde1aaa70633.mp4",
    "https://telegra.ph/file/07bba6ead0f1e381b1bd1.mp4",
    "https://telegra.ph/file/0a4f7935df9b4ab8d62ed.mp4",
    "https://telegra.ph/file/40966bf68c0e4dbe18058.mp4",
    "https://telegra.ph/file/50637aa9c04d136687523.mp4",
    "https://telegra.ph/file/b81c0b0e491da73e64260.mp4",
    "https://telegra.ph/file/4ddf5f29783d92ae03804.mp4",
    "https://telegra.ph/file/4037dc2517b702cc208b1.mp4",
    "https://telegra.ph/file/33cebe2798c15d52a2547.mp4",
    "https://telegra.ph/file/4dc3c8b03616da516104a.mp4",
    "https://telegra.ph/file/6b148dace4d987fae8f3e.mp4",
    "https://telegra.ph/file/8cb081db4eeed88767635.mp4",
    "https://telegra.ph/file/98d3eb94e6f00ed56ef91.mp4",
    "https://telegra.ph/file/1fb387cf99e057b62d75d.mp4",
    "https://telegra.ph/file/6e1161f63879c07a1f213.mp4",
    "https://telegra.ph/file/0bf4defb9540d2fa6d277.mp4",
    "https://telegra.ph/file/d5f8280754d9aa5dffa6a.mp4",
    "https://telegra.ph/file/0f23807ed1930704e2bef.jpg",
    "https://telegra.ph/file/c49280b8f1dcecaf86c00.jpg",
    "https://telegra.ph/file/f483400ff141de73767ca.jpg",
    "https://telegra.ph/file/1543bbea4e3c1abb6764a.jpg",
    "https://telegra.ph/file/a0d77be0d769c7cd334ab.jpg",
    "https://telegra.ph/file/6c6e93860527d2f577df8.jpg",
    "https://telegra.ph/file/d987b0e72eb3bb4801f01.jpg",
    "https://telegra.ph/file/b434999287d3580250960.jpg",
    "https://telegra.ph/file/0729cc082bf97347988f7.jpg",
    "https://telegra.ph/file/bb96d25df82178a2892e7.jpg",
    "https://telegra.ph/file/be73515791ea33be92a7d.jpg",
    "https://telegra.ph/file/fe234d6273093282d2dcc.jpg",
    "https://telegra.ph/file/66254bb72aa8094d38250.jpg",
    "https://telegra.ph/file/44bdaf37e5f7bdfc53ac6.jpg",
    "https://telegra.ph/file/e561ee1e1ca88db7e8038.jpg",
    "https://telegra.ph/file/f1960ccfc866b29ea5ad2.jpg",
    "https://telegra.ph/file/97622cad291472fb3c4aa.jpg",
    "https://telegra.ph/file/a46e316b413e9dc43e91b.jpg",
    "https://telegra.ph/file/497580fc3bddc21e0e162.jpg",
    "https://telegra.ph/file/3e86cc6cab06a6e2bde82.jpg",
    "https://telegra.ph/file/83140e2c57ddd95f310e6.jpg",
    "https://telegra.ph/file/2b20f8509d9437e94fed5.jpg",
    "https://telegra.ph/file/571960dcee4fce56698a4.jpg",
    "https://telegra.ph/file/25929a0b49452d8946c14.mp4",
    "https://telegra.ph/file/f5c9ceded3ee6e76a5931.jpg",
    "https://telegra.ph/file/a8bf6c6df8a48e4a306ca.jpg",
    "https://telegra.ph/file/af9e3f98da0bd937adf6e.jpg",
]



from pyrogram.types import InlineKeyboardButton

async def start_cmd(Legend):
    x = await Legend.get_me()
    START_OP = [
        [
            InlineKeyboardButton(
                text="🥀 Developer 🥀", url=f"https://t.me/Tashribots2342"
            ),
            InlineKeyboardButton(
                text="✨ Support ✨", url=f"https://t.me/TeamTashri"
            ),
        ],
        [
            InlineKeyboardButton(
                text="🧸 Add me in your group 🧸",
                url=f"https://t.me/{x.username}?startgroup=true",
            ),
        ],
        [
            InlineKeyboardButton(
                text="❄️ Repo ❄️", url=f"https://github.com/Tashri2342/BOTSPAM"
            ),
            InlineKeyboardButton(
                text="☁️ Updates ☁️", url=f"https://t.me/Tashribots2342"
            ),
        ],
    ]
    return START_OP



loveraid = [
    "HATE ME I DONT CARE",
    "LEAVE ME I DONT CARE",
    "EK TU H TU H RHYGII",
    "TERE BIN MAR JAUNGA",
    "TU MERI H SMJI?",
    "KOI TERE MERE BEECH AYA MARDUNGA OSE",
    "TERE LIYE MAR B SKTA HU MAR B SKTA HU",
    "TERE SE JITNA MRJI GUSSA HO JAUN BUT I LOVE U YARR",
    "TERE LIE IS DUNIA SE LAD JAUNGA",
    "ANKO SE ANKHE MILAKE KHWAB CHURA LU TERE",
    "TERA ISHQ PANE LIE KITNE BETAN HU KESE BATAU TUJE",
    "ME JO JEE RHA HU WAJH TUM HO",
    "TU H TO M HU TUJSE M HU",
    "TUJE KITNA CHAHNE LAGE HAM KI SHBO M BYAN NA KAR PAYNGE",
    "CURRENT STATUS  I WANT TO HUG YOU AND WANAA CARRY LOUD",
    "I NEED YOU IN MY BAD IN MY GOOD",
    "HMESHA TERE SATH HU",
    "TERE SE KADM SE KDM MILAKE CHALNA CHHTA HU",
    "TUJE APNI SHOTI SI DUNIA KA EK BHT BADA HISA BANANA CHAHTA HU",
    "KYA JANE TU MERE IRADHE LE JAUNGA TERI SANSE CHURAKE",
    "DIL KHE RHA KI GUNHGAGAR BAN JA BADA SKOON H IN GUNAHO M",
    "MERI KHUSHNMA SUBH H TU",
    "MERI JAAN H TU",
    "EVEN TUJE IDEA B NHI H KI TERE EK SINGLE MESSAGE KA WAIT KRTE KRTE KITAN ROYA HU",
    "TUJE PANE LIE BHT TDFA HU",
    "KABI KABI LGTA H KI TUN MUJSE NHT DUR JA RHI H",
    "I DONT CARE ABOUT WORD BS I NEED YOU",
    "TUN BAS MERI H MERI RHNA",
    "BHT ROTA HU TERE LIE AKELA ME",
    "H YE NSHA YAN H JEHAR IS PYAR KO KYA NAM DU",
    "HMARE PYAR KI H YE ADHURI DASTA KI TUN PASS HOKE B BHT DOOR H",
    "PLZZ KABI MAT SHODNA MUJE I CANT LIVE WITHOUT YOU",
    "DO JISM H BUT EK JAAN H HAM DO",
    "MUJE BAS TU CHHIE NAHI PTA KYU BUT CHHIE TU H",
    "THERE ARE MANY PEOPLE IN WORLD BUT I ONLY NEED YOU",
    "WO TERA GUSSA HONA JHGDE KRNE I MISS YOU",
    "BHT PYAR KRTA HU TERE SE PLZZ DONT LEAVE ME",
]



import time

def get_time(time: int):
    if time >= 86400:
        time = int(time / (60 * 60 * 24))
        unit = "days"
    elif time >= 3600 < 86400:
        time = int(time / (60 * 60))
        unit = "hours"
    elif time >= 60 < 3600:
        time = int(time / 60)
        unit = "minutes"
    else:
        return "Just Wait a Few Minutes Then Try Me"
    return f" {time} {unit}"



from pyrogram.types import BotCommand
from datetime import datetime, timedelta
import asyncio
from pyrogram.errors import FloodWait


async def start_bot(Client):
    await Client.start()
    try:
        x = await Client.get_me()
        print("➖➖➖➖❤️ Bᴏᴛ Iɴғᴏ ❤️➖➖➖➖")
        print(f"Bot Nᴀᴍᴇ = {x.first_name} {x.last_name}")
        print(f"Bot Usᴇʀɴᴀᴍᴇ = @{x.username} ɢᴇᴛ sᴛᴀʀᴛᴇᴅ")
        print("➖➖➖➖➖❤️❤️❤️❤️❤️➖➖➖➖➖")
    except FloodWait as e:
        curr_time = datetime.now()
        print("➖➖➖➖➖➖➖➖➖➖➖➖➖")
        print(f"Cᴜʀʀᴇɴᴛ Tɪᴍᴇ = {curr_time}")
        print(f"Hᴇʟʟᴏ Sɪʀ Yᴏᴜ Gᴇᴛ Fʟᴏᴏᴅ Wᴀɪᴛ Fᴏʀ {e.value}")
        print(f"Tʜᴇ Bᴏᴛ Wɪʟʟ Aᴜᴛᴏᴍᴀᴛɪᴄᴀʟʟʏ Gᴇᴛ Sᴛᴀʀᴛᴇᴅ Aᴛ Tɪᴍᴇ = curr_time + timedelta(seconds = {e.value})")
        print("➖➖➖➖➖➖➖➖➖➖➖➖➖")
        await asyncio.sleep(e.value)
    except Exception as e:
        print(e)
    try:
        print("sᴇᴛᴛɪɴɢ Aʟʟ Cᴏᴍᴍᴀɴᴅs")
        await Client.set_bot_commands(
            [
                BotCommand("start", "Start Bot By Anyone"),
                BotCommand("help", "Check the help menu of BotSpam"),
                BotCommand("ping", "Check that bot is alive or dead"),
                BotCommand("banall", "banall the member in Group"),
                BotCommand("birthday", "spam the chat with birthday message"),
                BotCommand("restart", "Restart The Bot"),
                BotCommand("eval", "Run Python Code"),
                BotCommand("exec", "Install The Requirements"),
                BotCommand("gm", "Spam The Chat with good morning message"),
                BotCommand("ga", "Spam The Chat With Good Afternoon Messages"),
                BotCommand("gn", "Spam The Chat With Good Night Message"),
                BotCommand("raid", "Spam The Chat With Raid"),
                BotCommand("rraid", "Start The Raid in Chat By Replying to person"),
                BotCommand("draid", "Stop The Raid in Chat"),
                BotCommand("listraid", "Check the list on started raid on it"),
                BotCommand("shayri", "Spam in chat with shayri"),
                BotCommand("stop", "To stop unlimited spam, raid, abuse"),
                BotCommand("dspam", "Start the chat with delay spam"),
                BotCommand("pspam", "Pornspam with raid"),
                BotCommand("hang", "Start hang command used to hang the chat"),
                BotCommand("uspam", "Start the Spam till used command stoo"),
                BotCommand("uraid", "Start the unlimited raid"),
                BotCommand("abuse", "Start abusing non stop"),
                BotCommand("echo", "echo the reply msg.")
                ]
            )
        print("Done All commands set successfully")

    except Exception as loll:
        print(loll)
        



SHAYRI = [
    "🌺**बहुत अच्छा लगता है तुझे सताना और फिर प्यार से तुझे मनाना।**🌺 \n\n**🥀Bahut aacha lagta hai tujhe satana Aur fir pyar se tujhe manana.🥀**", 
    "🌺**मेरी जिंदगी मेरी जान हो तुम मेरे सुकून का दुसरा नाम हो तुम।**🌺 \n\n**🥀Meri zindagi Meri jaan ho tum Mere sukoon ka Dusra naam ho tum.🥀** ", 
    "🌺**तुम मेरी वो खुशी हो जिसके बिना, मेरी सारी खुशी अधूरी लगती है।**🌺 \n\n**🥀**Tum Meri Wo Khushi Ho Jiske Bina, Meri Saari Khushi Adhuri Lagti Ha.🥀** ", 
    "🌺**काश वो दिन जल्दी आए,जब तू मेरे साथ सात फेरो में बन्ध जाए।**🌺 \n\n**🥀Kash woh din jldi aaye Jb tu mere sath 7 feron me bndh jaye.🥀** ", 
    "🌺**अपना हाथ मेरे दिल पर रख दो और अपना दिल मेरे नाम कर दो।**🌺 \n\n**🥀apna hath mere dil pr rakh do aur apna dil mere naam kar do.🥀** ", 
    "🌺**महादेव ना कोई गाड़ी ना कोई बंगला चाहिए सलामत रहे मेरा प्यार बस यही दुआ चाहिए।**🌺 \n\n**🥀Mahadev na koi gadi na koi bangla chahiye salamat rhe mera pyar bas yahi dua chahiye.🥀** ", 
    "🌺**फिक्र तो होगी ना तुम्हारी इकलौती मोहब्बत हो तुम मेरी।**🌺 \n\n**🥀Fikr to hogi na tumhari ikloti mohabbat ho tum meri.🥀** ", 
    "🌺**सुनो जानू आप सिर्फ किचन संभाल लेना आप को संभालने के लिए मैं हूं ना।**🌺 \n\n**🥀suno jaanu aap sirf kitchen sambhal lena ap ko sambhlne ke liye me hun naa.🥀** ", 
    "🌺**सौ बात की एक बात मुझे चाहिए बस तेरा साथ।**🌺 \n\n**🥀So bat ki ek bat mujhe chahiye bas tera sath.🥀** ", 
    "🌺**बहुत मुश्किलों से पाया हैं तुम्हें, अब खोना नहीं चाहते,कि तुम्हारे थे तुम्हारे हैं अब किसी और के होना नहीं चाहते।**🌺 \n\n**🥀Bahut muskilon se paya hai tumhe Ab khona ni chahte ki tumhare they tumhare hai ab kisi or k hona nhi chahte.🥀** ", 
    "🌺**बेबी बातें तो रोज करते है चलो आज रोमांस करते है।**🌺 \n\n**🥀Baby baten to roj karte haichalo aaj romance karte hai..🥀** ", 
    "🌺**सुबह शाम तुझे याद करते है हम और क्या बताएं की तुमसे कितना प्यार करते है हम।**🌺 \n\n**🥀subha sham tujhe yad karte hai hum aur kya batayen ki tumse kitna pyar karte hai hum.🥀** ", 
    "🌺**किसी से दिल लग जाने को मोहब्बत नहीं कहते जिसके बिना दिल न लगे उसे मोहब्बत कहते हैं।**🌺 \n\n**🥀Kisi se dil lag jane ko mohabbat nahi kehte jiske nina dil na lage use mohabbat kehte hai.🥀** ", 
    " 🌺**मेरे दिल के लॉक की चाबी हो तुम क्या बताएं जान मेरे जीने की एकलौती वजह हो तुम।**🌺 \n\n**🥀mere dil ke lock ki chabi ho tum kya batayen jaan mere jeene ki eklauti wajah ho tum..🥀** ", 
    " 🌺**हम आपकी हर चीज़ से प्यार कर लेंगे, आपकी हर बात पर ऐतबार कर लेंगे, बस एक बार कह दो कि तुम सिर्फ मेरे हो, हम ज़िन्दगी भर आपका इंतज़ार कर लेंगे।**🌺 \n\n**🥀Hum apki har cheez se pyar kar lenge apki har baat par etvar kar lenge bas ek bar keh do ki tum sirf mere ho hum zindagi bhar apka intzaar kar lenge..🥀** ", 
    " 🌺**मोहब्बत कभी स्पेशल लोगो से नहीं होती जिससे होती है वही स्पेशल बन जाता है।**🌺 \n\n**🥀Mohabbat kabhi special logo se nahi hoti jisse bhi hoti hai wahi special ban jate hai,.🥀**", 
    " 🌺**तू मेरी जान है इसमें कोई शक नहीं तेरे अलावा मुझ पर किसी और का हक़ नहीं।**🌺 \n\n**🥀Tu meri jaan hai isme koi shak nahi tere alawa mujhe par kisi aur ka hak nhi..🥀** ", 
    " 🌺**पहली मोहब्बत मेरी हम जान न सके, प्यार क्या होता है हम पहचान न सके, हमने उन्हें दिल में बसा लिया इस कदर कि, जब चाहा उन्हें दिल से निकाल न सके।**🌺 \n\n**🥀Pehli mohabbat meri hum jaan na sake pyar kya hota hai hum pehchan na sake humne unhe dil me basa liya is kadar ki jab chaha unhe dil se nikal na sake.🥀** ", 
    " 🌺**खुद नहीं जानती वो कितनी प्यारी हैं , जान है हमारी पर जान से प्यारी हैं, दूरियों के होने से कोई फर्क नहीं पड़ता वो कल भी हमारी थी और आज भी हमारी है.**🌺 \n\n**🥀khud nahi janti vo kitni pyari hai jan hai hamari par jan se jyda payari hai duriya ke hone se frak nahi pdta vo kal bhe hamari the or aaj bhe hamari hai.🥀** ", 
    " 🌺**चुपके से आकर इस दिल में उतर जाते हो, सांसों में मेरी खुशबु बनके बिखर जाते हो, कुछ यूँ चला है तेरे इश्क का जादू, सोते-जागते तुम ही तुम नज़र आते हो।**🌺 \n\n**🥀Chupke Se Aakar Iss Dil Mein Utar Jate Ho, Saanso Mein Meri Khushbu BanKe Bikhar Jate Ho,Kuchh Yun Chala Hai Tere Ishq Ka Jadoo, Sote-Jagte Tum Hi Tum Najar Aate Ho..🥀** ", 
    " 🌺**प्यार करना सिखा है नफरतो का कोई ठौर नही, बस तु ही तु है इस दिल मे दूसरा कोई और नही.**🌺 \n\n**🥀Pyar karna sikha hai naftaro ka koi thor nahi bas tu hi tu hai is dil me dusra koi aur nahi hai.🥀** ", 
    " 🌺**रब से आपकी खुशीयां मांगते है, दुआओं में आपकी हंसी मांगते है, सोचते है आपसे क्या मांगे,चलो आपसे उम्र भर की मोहब्बत मांगते है।**🌺\n\n**🥀Rab se apki khushiyan mangte hai duao me apki hansi mangte hai sochte hai apse kya mange chalo apse umar bhar ki mohabbat mangte hai..🥀** ", 
    " 🌺**काश मेरे होंठ तेरे होंठों को छू जाए देखूं जहा बस तेरा ही चेहरा नज़र आए हो जाए हमारा रिश्ता कुछ ऐसा होंठों के साथ हमारे दिल भी जुड़ जाए.**🌺\n\n**🥀kash mere hoth tere hontho ko chu jayen dekhun jaha bas teri hi chehra nazar aaye ho jayen humara rishta kuch easa hothon ke sath humare dil bhi jud jaye.🥀** ", 
    " 🌺**आज मुझे ये बताने की इजाज़त दे दो, आज मुझे ये शाम सजाने की इजाज़त दे दो, अपने इश्क़ मे मुझे क़ैद कर लो,आज जान तुम पर लूटाने की इजाज़त दे दो.**🌺\n\n**🥀Aaj mujhe ye batane ki izazat de do, aaj mujhe ye sham sajane ki izazat de do, apne ishq me mujhe ked kr lo aaj jaan tum par lutane ki izazat de do..🥀** ", 
    " 🌺**जाने लोग मोहब्बत को क्या क्या नाम देते है, हम तो तेरे नाम को ही मोहब्बत कहते है.**🌺\n\n**🥀Jane log mohabbat ko kya kya naam dete hai hum to tere naam ko hi mohabbat kehte hai..🥀** ", 
    " 🌺**देख के हमें वो सिर झुकाते हैं। बुला के महफिल में नजर चुराते हैं। नफरत हैं हमसे तो भी कोई बात नहीं। पर गैरो से मिल के दिल क्यों जलाते हो।**🌺\n\n**🥀Dekh Ke Hame Wo Sir Jhukate Hai Bula Ke Mahfhil Me Najar Churate Hai Nafrat Hai Hamse To Bhi Koei Bat Nhi Par Gairo Se Mil Ke Dil Kyo Jalate Ho.🥀** ", 
    " 🌺**तेरे बिना टूट कर बिखर जायेंगे,तुम मिल गए तो गुलशन की तरह खिल जायेंगे, तुम ना मिले तो जीते जी ही मर जायेंगे, तुम्हें जो पा लिया तो मर कर भी जी जायेंगे।**🌺\n\n**🥀Tere bina tut kar bikhar jeynge tum mil gaye to gulshan ki tarha khil jayenge tum na mile to jite ji hi mar jayenge tumhe jo pa liya to mar kar bhi ji jayenge..🥀** ", 
    " 🌺**सनम तेरी कसम जेसे मै जरूरी हूँ तेरी ख़ुशी के लिये, तू जरूरी है मेरी जिंदगी के लिये.**🌺\n\n**🥀Sanam teri kasam jese me zaruri hun teri khushi ke liye tu zaruri hai meri zindagi ke liye.🥀** ", 
    " 🌺**तुम्हारे गुस्से पर मुझे बड़ा प्यार आया हैं इस बेदर्द दुनिया में कोई तो हैं जिसने मुझे पुरे हक्क से धमकाया हैं.**🌺\n\n**🥀Tumharfe gusse par mujhe pyar aaya hai is bedard duniya me koi to hai jisne mujhe pure hakk se dhamkaya hai.🥀** ", 
    " 🌺**पलको से आँखो की हिफाजत होती है धडकन दिल की अमानत होती है ये रिश्ता भी बडा प्यारा होता है कभी चाहत तो कभी शिकायत होती है.**🌺\n\n**🥀Palkon se Aankho ki hifajat hoti hai dhakad dil ki Aamanat hoti hai, ye rishta bhi bada pyara hota hai, kabhi chahat to kabhi shikayat hoti hai.🥀** ", 
    " 🌺**मुहब्बत को जब लोग खुदा मानते हैं प्यार करने वाले को क्यों बुरा मानते हैं। जब जमाना ही पत्थर दिल हैं। फिर पत्थर से लोग क्यों दुआ मांगते है।**🌺\n\n**🥀Muhabbt Ko Hab Log Khuda Mante Hai, Payar Karne Walo Ko Kyu Bura Mante Hai,Jab Jamana Hi Patthr Dil Hai,Fhir Patthr Se Log Kyu Duaa Magte Hai.🥀** ", 
    " 🌺**हुआ जब इश्क़ का एहसास उन्हें आकर वो पास हमारे सारा दिन रोते रहे हम भी निकले खुदगर्ज़ इतने यारो कि ओढ़ कर कफ़न, आँखें बंद करके सोते रहे।**🌺\n\n**🥀Hua jab ishq ka ehsaas unhe akar wo pass humare sara din rate rahe, hum bhi nikale khudgarj itne yaro ki ood kar kafan ankhe band krke sote rhe.🥀** ", 
    " 🌺**दिल के कोने से एक आवाज़ आती हैं। हमें हर पल उनकी याद आती हैं। दिल पुछता हैं बार -बार हमसे के जितना हम याद करते हैं उन्हें क्या उन्हें भी हमारी याद आती हैं।**🌺\n\n**🥀Dil Ke Kone Se Ek Aawaj Aati Hai, Hame Har Pal Uaski Yad Aati Hai, Dil Puchhta Hai Bar Bar Hamse Ke, Jitna Ham Yad Karte Hai Uanhe, Kya Uanhe Bhi Hamari Yad Aati Hai,🥀** ", 
    " 🌺**कभी लफ्ज़ भूल जाऊं कभी बात भूल जाऊं, तूझे इस कदर चाहूँ कि अपनी जात भूल जाऊं, कभी उठ के तेरे पास से जो मैं चल दूँ, जाते हुए खुद को तेरे पास भूल जाऊं।**🌺\n\n**🥀Kabhi Lafz Bhool Jaaun Kabhi Baat Bhool Jaaun, Tujhe Iss Kadar Chahun Ki Apni Jaat Bhool Jaaun, Kabhi Uthh Ke Tere Paas Se Jo Main Chal Dun, Jaate Huye Khud Ko Tere Paas Bhool Jaaun..🥀** ", 
    " 🌺**आईना देखोगे तो मेरी याद आएगी साथ गुज़री वो मुलाकात याद आएगी पल भर क लिए वक़्त ठहर जाएगा, जब आपको मेरी कोई बात याद आएगी.**🌺\n\n**🥀Aaina dekhoge to meri yad ayegi sath guzari wo mulakat yad ayegi pal bhar ke waqt thahar jayega jab apko meri koi bat yad ayegi.🥀** ", 
    " 🌺**प्यार किया तो उनकी मोहब्बत नज़र आई दर्द हुआ तो पलके उनकी भर आई दो दिलों की धड़कन में एक बात नज़र आई दिल तो उनका धड़का पर आवाज़ इस दिल की आई.**🌺\n\n**🥀Pyar kiya to unki mohabbat nazar aai dard hua to palke unki bhar aai do dilon ki dhadkan me ek baat nazar aai dil to unka dhadka par awaz dil ki aai.🥀** ", 
    " 🌺**कई चेहरे लेकर लोग यहाँ जिया करते हैं हम तो बस एक ही चेहरे से प्यार करते हैं ना छुपाया करो तुम इस चेहरे को,क्योंकि हम इसे देख के ही जिया करते हैं.**🌺\n\n**🥀Kai chehre lekar log yahn jiya karte hai hum to bas ek hi chehre se pyar karte hai na chupaya karo tum is chehre ko kyuki hum ise dekh ke hi jiya karte hai.🥀** ", 
    " 🌺**सबके bf को अपनी gf से बात करके नींद आजाती है और मेरे वाले को मुझसे लड़े बिना नींद नहीं आती।**🌺\n\n**🥀Sabke bf ko apni gf se baat karke nind aajati hai aur mere wale ko mujhse lade bina nind nhi aati.🥀** ", 
    " 🌺**सच्चा प्यार कहा किसी के नसीब में होता है. एसा प्यार कहा इस दुनिया में किसी को नसीब होता है.**🌺\n\n**🥀Sacha pyar kaha kisi ke nasib me hota hai esa pyar kahan is duniya me kisi ko nasib hota hai.🥀** ",
]

RAID = [
    "MADARCHOD TERI MAA KI CHUT ME GHUTKA KHAAKE THOOK DUNGA 🤣🤣",
    "TERE BEHEN K CHUT ME CHAKU DAAL KAR CHUT KA KHOON KAR DUGA",
    "TERI VAHEEN NHI HAI KYA? 9 MAHINE RUK SAGI VAHEEN DETA HU 🤣🤣🤩",
    "TERI MAA K BHOSDE ME AEROPLANEPARK KARKE UDAAN BHAR DUGA ✈️🛫",
    "TERI MAA KI CHUT ME SUTLI BOMB FOD DUNGA TERI MAA KI JHAATE JAL KE KHAAK HO JAYEGI💣",
    "TERI MAAKI CHUT ME SCOOTER DAAL DUGA👅",
    "TERE BEHEN K CHUT ME CHAKU DAAL KAR CHUT KA KHOON KAR DUGA",
    "TERE BEHEN K CHUT ME CHAKU DAAL KAR CHUT KA KHOON KAR DUGA",
    "TERI MAA KI CHUT KAKTE 🤱 GALI KE KUTTO 🦮 ME BAAT DUNGA PHIR 🍞 BREAD KI TARH KHAYENGE WO TERI MAA KI CHUT",
    "DUDH HILAAUNGA TERI VAHEEN KE UPR NICHE 🆙🆒😙",
    "TERI MAA KI CHUT ME ✋ HATTH DALKE 👶 BACCHE NIKAL DUNGA 😍",
    "TERI BEHN KI CHUT ME KELE KE CHILKE 🍌🍌😍",
    "TERI BHEN KI CHUT ME USERBOT LAGAAUNGA SASTE SPAM KE CHODE",
    "TERI VAHEEN DHANDHE VAALI 😋😛",
    "TERI MAA KE BHOSDE ME AC LAGA DUNGA SAARI GARMI NIKAL JAAYEGI",
    "TERI VAHEEN KO HORLICKS PEELAUNGA MADARCHOD😚",
    "TERI MAA KI GAAND ME SARIYA DAAL DUNGA MADARCHOD USI SARIYE PR TANG KE BACHE PAIDA HONGE 😱😱",
    "TERI MAA KO KOLKATA VAALE JITU BHAIYA KA LUND MUBARAK 🤩🤩",
    "TERI MUMMY KI FANTASY HU LAWDE, TU APNI BHEN KO SMBHAAL 😈😈",
    "TERA PEHLA BAAP HU MADARCHOD ",
    "TERI VAHEEN KE BHOSDE ME XVIDEOS.COM CHALA KE MUTH MAARUNGA 🤡😹",
    "TERI MAA KA GROUP VAALON SAATH MILKE GANG BANG KRUNGA🙌🏻☠️ ",
    "TERI ITEM KI GAAND ME LUND DAALKE,TERE JAISA EK OR NIKAAL DUNGA MADARCHOD🤘🏻🙌🏻☠️ ",
    "AUKAAT ME REH VRNA GAAND ME DANDA DAAL KE MUH SE NIKAAL DUNGA SHARIR BHI DANDE JESA DIKHEGA 🙄🤭🤭",
    "TERI MUMMY KE SAATH LUDO KHELTE KHELTE USKE MUH ME APNA LODA DE DUNGA☝🏻☝🏻😬",
    "TERI VAHEEN KO APNE LUND PR ITNA JHULAAUNGA KI JHULTE JHULTE HI BACHA PAIDA KR DEGI👀👯 ",
    "TERI MAA KI CHUT MEI BATTERY LAGA KE POWERBANK BANA DUNGA 🔋 🔥🤩",
    "TERI MAA KI CHUT MEI C++ STRING ENCRYPTION LAGA DUNGA BAHTI HUYI CHUT RUK JAYEGIIII😈🔥😍",
    "TERI MAA KE GAAND MEI JHAADU DAL KE MOR 🦚 BANA DUNGAA 🤩🥵😱",
    "TERI CHUT KI CHUT MEI SHOULDERING KAR DUNGAA HILATE HUYE BHI DARD HOGAAA😱🤮👺",
    "TERI MAA KO REDI PE BAITHAL KE USSE USKI CHUT BILWAUNGAA 💰 😵🤩",
    "BHOSDIKE TERI MAA KI CHUT MEI 4 HOLE HAI UNME MSEAL LAGA BAHUT BAHETI HAI BHOFDIKE👊🤮🤢🤢",
    "TERI BAHEN KI CHUT MEI BARGAD KA PED UGA DUNGAA CORONA MEI SAB OXYGEN LEKAR JAYENGE🤢🤩🥳",
    "TERI MAA KI CHUT MEI SUDO LAGA KE BIGSPAM LAGA KE 9999 FUCK LAGAA DU 🤩🥳🔥",
    "TERI VAHEN KE BHOSDIKE MEI BESAN KE LADDU BHAR DUNGA🤩🥳🔥😈",
    "TERI MAA KI CHUT KHOD KE USME CYLINDER ⛽️ FIT KARKE USMEE DAL MAKHANI BANAUNGAAA🤩👊🔥",
    "TERI MAA KI CHUT MEI SHEESHA DAL DUNGAAA AUR CHAURAHE PE TAANG DUNGA BHOSDIKE😈😱🤩",
    "TERI MAA KI CHUT MEI CREDIT CARD DAL KE AGE SE 500 KE KAARE KAARE NOTE NIKALUNGAA BHOSDIKE💰💰🤩",
    "TERI MAA KE SATH SUAR KA SEX KARWA DUNGAA EK SATH 6-6 BACHE DEGI💰🔥😱",
    "TERI BAHEN KI CHUT MEI APPLE KA 18W WALA CHARGER 🔥🤩",
    "TERI BAHEN KI GAAND MEI ONEPLUS KA WRAP CHARGER 30W HIGH POWER 💥😂😎",
    "TERI BAHEN KI CHUT KO AMAZON SE ORDER KARUNGA 10 rs MEI AUR FLIPKART PE 20 RS MEI BECH DUNGA🤮👿😈🤖",
    "TERI MAA KI BADI BHUND ME ZOMATO DAL KE SUBWAY KA BFF VEG SUB COMBO [15cm , 16 inches ] ORDER COD KRVAUNGA OR TERI MAA JAB DILIVERY DENE AYEGI TAB USPE JAADU KRUNGA OR FIR 9 MONTH BAAD VO EK OR FREE DILIVERY DEGI🙀👍🥳🔥",
    "TERI BHEN KI CHUT KAALI🙁🤣💥",
    "TERI MAA KI CHUT ME CHANGES COMMIT KRUGA FIR TERI BHEEN KI CHUT AUTOMATICALLY UPDATE HOJAAYEGI🤖🙏🤔",
    "TERI MAUSI KE BHOSDE MEI INDIAN RAILWAY 🚂💥😂",
    "TU TERI BAHEN TERA KHANDAN SAB BAHEN KE LAWDE RANDI HAI RANDI 🤢✅🔥",
    "TERI BAHEN KI CHUT MEI IONIC BOND BANA KE VIRGINITY LOOSE KARWA DUNGA USKI 📚 😎🤩",
    "TERI RANDI MAA SE PUCHNA BAAP KA NAAM BAHEN KE LODEEEEE 🤩🥳😳",
    "TU AUR TERI MAA DONO KI BHOSDE MEI METRO CHALWA DUNGA MADARXHOD 🚇🤩😱🥶",
    "TERI MAA KO ITNA CHODUNGA TERA BAAP BHI USKO PAHCHANANE SE MANA KAR DEGA😂👿🤩",
    "TERI BAHEN KE BHOSDE MEI HAIR DRYER CHALA DUNGAA💥🔥🔥",
    "TERI MAA KI CHUT MEI TELEGRAM KI SARI RANDIYON KA RANDI KHANA KHOL DUNGAA👿🤮😎",
    "TERI MAA KI CHUT ALEXA DAL KEE DJ BAJAUNGAAA 🎶 ⬆️🤩💥",
    "TERI MAA KE BHOSDE MEI GITHUB DAL KE APNA BOT HOST KARUNGAA 🤩👊👤😍",
    "TERI BAHEN KA VPS BANA KE 24*7 BASH CHUDAI COMMAND DE DUNGAA 🤩💥🔥🔥",
    "TERI MUMMY KI CHUT MEI TERE LAND KO DAL KE KAAT DUNGA MADARCHOD 🔪😂🔥",
    "SUN TERI MAA KA BHOSDA AUR TERI BAHEN KA BHI BHOSDA 👿😎👊",
    "TUJHE DEKH KE TERI RANDI BAHEN PE TARAS ATA HAI MUJHE BAHEN KE LODEEEE 👿💥🤩🔥",
    "SUN MADARCHOD JYADA NA UCHAL MAA CHOD DENGE EK MIN MEI ✅🤣🔥🤩",
    "APNI AMMA SE PUCHNA USKO US KAALI RAAT MEI KAUN CHODNEE AYA THAAA! TERE IS PAPA KA NAAM LEGI 😂👿😳",
    "TOHAR BAHIN CHODU BBAHEN KE LAWDE USME MITTI DAL KE CEMENT SE BHAR DU 🏠🤢🤩💥",
    "TUJHE AB TAK NAHI SMJH AYA KI MAI HI HU TUJHE PAIDA KARNE WALA BHOSDIKEE APNI MAA SE PUCH RANDI KE BACHEEEE 🤩👊👤😍",
    "TERI MAA KE BHOSDE MEI SPOTIFY DAL KE LOFI BAJAUNGA DIN BHAR 😍🎶🎶💥",
    "TERI MAA KA NAYA RANDI KHANA KHOLUNGA CHINTA MAT KAR 👊🤣🤣😳",
    "TERA BAAP HU BHOSDIKE TERI MAA KO RANDI KHANE PE CHUDWA KE US PAISE KI DAARU PEETA HU 🍷🤩🔥",
    "TERI BAHEN KI CHUT MEI APNA BADA SA LODA GHUSSA DUNGAA KALLAAP KE MAR JAYEGI 🤩😳😳🔥",
    "TOHAR MUMMY KI CHUT MEI PURI KI PURI KINGFISHER KI BOTTLE DAL KE TOD DUNGA ANDER HI 😱😂🤩",
    "TERI MAA KO ITNA CHODUNGA KI SAPNE MEI BHI MERI CHUDAI YAAD KAREGI RANDI 🥳😍👊💥",
    "TERI MUMMY AUR BAHEN KO DAUDA DAUDA NE CHODUNGA UNKE NO BOLNE PE BHI LAND GHUSA DUNGA ANDER TAK 😎😎🤣🔥",
    "TERI MUMMY KI CHUT KO ONLINE OLX PE BECHUNGA AUR PAISE SE TERI BAHEN KA KOTHA KHOL DUNGA 😎🤩😝😍",
    "TERI MAA KE BHOSDA ITNA CHODUNGA KI TU CAH KE BHI WO MAST CHUDAI SE DUR NHI JA PAYEGAA 😏😏🤩😍",
    "SUN BE RANDI KI AULAAD TU APNI BAHEN SE SEEKH KUCH KAISE GAAND MARWATE HAI😏🤬🔥💥",
    "TERI MAA KA YAAR HU MEI AUR TERI BAHEN KA PYAAR HU MEI AJA MERA LAND CHOOS LE 🤩🤣💥",
    "TERI BHEN KI CHUT ME USERBOT LAGAAUNGA SASTE SPAM KE CHODE",
    "TERI MAA KI GAAND ME SARIYA DAAL DUNGA MADARCHOD USI SARIYE PR TANG KE BACHE PAIDA HONGE 😱😱",
    "TERI MAA KI CHUT ME ✋ HATTH DALKE 👶 BACCHE NIKAL DUNGA 😍",
    "TERI BEHN KI CHUT ME KELE KE CHILKE 🤤🤤",
    "TERI MAA KI CHUT ME SUTLI BOMB FOD DUNGA TERI MAA KI JHAATE JAL KE KHAAK HO JAYEGI💣💋",
    "TERI VAHEEN KO HORLICKS PEELAKE CHODUNGA MADARCHOD😚",
    "TERI ITEM KI GAAND ME LUND DAALKE,TERE JAISA EK OR NIKAAL DUNGA MADARCHOD😆🤤💋",
    "TERI VAHEEN KO APNE LUND PR ITNA JHULAAUNGA KI JHULTE JHULTE HI BACHA PAIDA KR DEGI 💦💋",
    "SUAR KE PILLE TERI MAAKO SADAK PR LITAKE CHOD DUNGA 😂😆🤤",
    "ABE TERI MAAKA BHOSDA MADERCHOOD KR PILLE PAPA SE LADEGA TU 😼😂🤤",
    "GALI GALI NE SHOR HE TERI MAA RANDI CHOR HE 💋💋💦",
    "ABE TERI BEHEN KO CHODU RANDIKE PILLE KUTTE KE CHODE 😂👻🔥",
    "TERI MAAKO AISE CHODA AISE CHODA TERI MAAA BED PEHI MUTH DIA 💦💦💦💦",
    "TERI BEHEN KE BHOSDE ME AAAG LAGADIA MERA MOTA LUND DALKE 🔥🔥💦😆😆",
    "RANDIKE BACHHE TERI MAAKO CHODU CHAL NIKAL",
    "KITNA CHODU TERI RANDI MAAKI CHUTH ABB APNI BEHEN KO BHEJ 😆👻🤤",
    "TERI BEHEN KOTO CHOD CHODKE PURA FAAD DIA CHUTH ABB TERI GF KO BHEJ 😆💦🤤",
    "TERI GF KO ETNA CHODA BEHEN KE LODE TERI GF TO MERI RANDI BANGAYI ABB CHAL TERI MAAKO CHODTA FIRSE ♥️💦😆😆😆😆",
    "HARI HARI GHAAS ME JHOPDA TERI MAAKA BHOSDA 🤣🤣💋💦",
    "CHAL TERE BAAP KO BHEJ TERA BASKA NHI HE PAPA SE LADEGA TU",
    "TERI BEHEN KI CHUTH ME BOMB DALKE UDA DUNGA MAAKE LAWDE",
    "TERI MAAKO TRAIN ME LEJAKE TOP BED PE LITAKE CHOD DUNGA SUAR KE PILLE 🤣🤣💋💋",
    "TERI MAAAKE NUDES GOOGLE PE UPLOAD KARDUNGA BEHEN KE LAEWDE 👻🔥",
    "TERI MAAAKE NUDES GOOGLE PE UPLOAD KARDUNGA BEHEN KE LAEWDE 👻🔥",
    "TERI BEHEN KO CHOD CHODKE VIDEO BANAKE XNXX.COM PE NEELAM KARDUNGA KUTTE KE PILLE 💦💋",
    "TERI MAAAKI CHUDAI KO PORNHUB.COM PE UPLOAD KARDUNGA SUAR KE CHODE 🤣💋💦",
    "ABE TERI BEHEN KO CHODU RANDIKE BACHHE TEREKO CHAKKO SE PILWAVUNGA RANDIKE BACHHE 🤣🤣",
    "TERI MAAKI CHUTH FAADKE RAKDIA MAAKE LODE JAA ABB SILWALE 👄👄",
    "TERI BEHEN KI CHUTH ME MERA LUND KAALA",
    "TERI BEHEN LETI MERI LUND BADE MASTI SE TERI BEHEN KO MENE CHOD DALA BOHOT SASTE SE",
    "BETE TU BAAP SE LEGA PANGA TERI MAAA KO CHOD DUNGA KARKE NANGA 💦💋",
    "HAHAHAH MERE BETE AGLI BAAR APNI MAAKO LEKE AAYA MATH KAT OR MERE MOTE LUND SE CHUDWAYA MATH KAR",
    "CHAL BETA TUJHE MAAF KIA 🤣 ABB APNI GF KO BHEJ",
    "SHARAM KAR TERI BEHEN KA BHOSDA KITNA GAALIA SUNWAYEGA APNI MAAA BEHEN KE UPER",
    "ABE RANDIKE BACHHE AUKAT NHI HETO APNI RANDI MAAKO LEKE AAYA MATH KAR HAHAHAHA",
    "KIDZ MADARCHOD TERI MAAKO CHOD CHODKE TERR LIYE BHAI DEDIYA",
    "JUNGLE ME NACHTA HE MORE TERI MAAKI CHUDAI DEKKE SAB BOLTE ONCE MORE ONCE MORE 🤣🤣💦💋",
    "GALI GALI ME REHTA HE SAND TERI MAAKO CHOD DALA OR BANA DIA RAND 🤤🤣",
    "SAB BOLTE MUJHKO PAPA KYOUNKI MENE BANADIA TERI MAAKO PREGNENT 🤣🤣",
    "SUAR KE PILLE TERI MAAKI CHUTH ME SUAR KA LOUDA OR TERI BEHEN KI CHUTH ME MERA LODA",
    "CHAL CHAL APNI MAAKI CHUCHIYA DIKA",
    "HAHAHAHA BACHHE TERI MAAAKO CHOD DIA NANGA KARKE",
    "TERI GF HE BADI SEXY USKO PILAKE CHOODENGE PEPSI",
    "2 RUPAY KI PEPSI TERI MUMMY SABSE SEXY 💋💦",
    "TERI MAAKO CHEEMS SE CHUDWAVUNGA MADERCHOOD KE PILLE 💦🤣",
    "TERI BEHEN KI CHUTH ME MUTHKE FARAR HOJAVUNGA HUI HUI HUI",
    "SPEED LAAA TERI BEHEN CHODU RANDIKE PILLE 💋💦🤣",
    "ARE RE MERE BETE KYOUN SPEED PAKAD NA PAAA RAHA APNE BAAP KA HAHAH🤣🤣",
    "SUN SUN SUAR KE PILLE JHANTO KE SOUDAGAR APNI MUMMY KI NUDES BHEJ",
    "ABE SUN LODE TERI BEHEN KA BHOSDA FAAD DUNGA",
    "TERI MAAKO KHULE BAJAR ME CHOD DALA 🤣🤣💋",
]


RRAID = [
    "MADARCHOD",
    "BHOSDIKE",
    "LAAAWEEE KE BAAAAAL",
    "MAAAAR KI JHAAAAT KE BBBBBAAAAALLLLL",
    "MADRCHOD..",
    "TERI MA KI CHUT..",
    "LWDE KE BAAALLL.",
    "MACHAR KI JHAAT KE BAAALLLL",
    "TERI MA KI CHUT M DU TAPA TAP?",
    "TERI MA KA BHOSDAA",
    "TERI BHN SBSBE BDI RANDI.",
    "TERI MA OSSE BADI RANDDDDD",
    "TERA BAAP CHKAAAA",
    "KITNI CHODU TERI MA AB OR..",
    "TERI MA CHOD DI HM NE",
    "TERI MA KE STH REELS BNEGA ROAD PEE",
    "TERI MA KI CHUT EK DAM TOP SEXY",
    "MALUM NA PHR KESE LETA HU M TERI MA KI CHUT TAPA TAPPPPP",
    "LUND KE CHODE TU KEREGA TYPIN",
    "SPEED PKD LWDEEEE",
    "BAAP KI SPEED MTCH KRRR",
    "LWDEEE",
    "PAPA KI SPEED MTCH NHI HO RHI KYA",
    "ALE ALE MELA BCHAAAA",
    "CHUD GYA PAPA SEEE",
    "KISAN KO KHODNA OR",
    "SALE RAPEKL KRDKA TERA",
    "HAHAHAAAAA",
    "KIDSSSS",
    "TERI MA CHUD GYI AB FRAR MT HONA",
    "YE LDNGE BAPP SE",
    "KIDSSS FRAR HAHAHH",
    "BHEN KE LWDE SHRM KR",
    "KITNI GLIYA PDWEGA APNI MA KO",
    "NALLEE",
    "SUAR KE PILLE TERI MAAKO SADAK PR LITAKE CHOD DUNGA 😂😆🤤",
    "ABE TERI MAAKA BHOSDA MADERCHOOD KR PILLE PAPA SE LADEGA TU 😼😂🤤",
    "GALI GALI NE SHOR HE TERI MAA RANDI CHOR HE 💋💋💦",
    "ABE TERI BEHEN KO CHODU RANDIKE PILLE KUTTE KE CHODE 😂👻🔥",
    "TERI MAAKO AISE CHODA AISE CHODA TERI MAAA BED PEHI MUTH DIA 💦💦💦💦",
    "TERI BEHEN KE BHOSDE ME AAAG LAGADIA MERA MOTA LUND DALKE 🔥🔥💦😆😆",
    "RANDIKE BACHHE TERI MAAKO CHODU CHAL NIKAL",
    "KITNA CHODU TERI RANDI MAAKI CHUTH ABB APNI BEHEN KO BHEJ 😆👻🤤",
    "TERI BEHEN KOTO CHOD CHODKE PURA FAAD DIA CHUTH ABB TERI GF KO BHEJ 😆💦🤤",
    "TERI GF KO ETNA CHODA BEHEN KE LODE TERI GF TO MERI RANDI BANGAYI ABB CHAL TERI MAAKO CHODTA FIRSE ♥️💦😆😆😆😆",
    "HARI HARI GHAAS ME JHOPDA TERI MAAKA BHOSDA 🤣🤣💋💦",
    "CHAL TERE BAAP KO BHEJ TERA BASKA NHI HE PAPA SE LADEGA TU",
    "TERI BEHEN KI CHUTH ME BOMB DALKE UDA DUNGA MAAKE LAWDE",
    "TERI MAAKO TRAIN ME LEJAKE TOP BED PE LITAKE CHOD DUNGA SUAR KE PILLE 🤣🤣💋💋",
    "TERI MAAAKE NUDES GOOGLE PE UPLOAD KARDUNGA BEHEN KE LAEWDE 👻🔥",
    "TERI MAAAKE NUDES GOOGLE PE UPLOAD KARDUNGA BEHEN KE LAEWDE 👻🔥",
    "TERI BEHEN KO CHOD CHODKE VIDEO BANAKE XNXX.COM PE NEELAM KARDUNGA KUTTE KE PILLE 💦💋",
    "TERI MAAAKI CHUDAI KO PORNHUB.COM PE UPLOAD KARDUNGA SUAR KE CHODE 🤣💋💦",
    "ABE TERI BEHEN KO CHODU RANDIKE BACHHE TEREKO CHAKKO SE PILWAVUNGA RANDIKE BACHHE 🤣🤣",
    "TERI MAAKI CHUTH FAADKE RAKDIA MAAKE LODE JAA ABB SILWALE 👄👄",
    "TERI BEHEN KI CHUTH ME MERA LUND KAALA",
    "TERI BEHEN LETI MERI LUND BADE MASTI SE TERI BEHEN KO MENE CHOD DALA BOHOT SASTE SE",
    "BETE TU BAAP SE LEGA PANGA TERI MAAA KO CHOD DUNGA KARKE NANGA 💦💋",
    "HAHAHAH MERE BETE AGLI BAAR APNI MAAKO LEKE AAYA MATH KAT OR MERE MOTE LUND SE CHUDWAYA MATH KAR",
    "CHAL BETA TUJHE MAAF KIA 🤣 ABB APNI GF KO BHEJ",
    "SHARAM KAR TERI BEHEN KA BHOSDA KITNA GAALIA SUNWAYEGA APNI MAAA BEHEN KE UPER",
    "ABE RANDIKE BACHHE AUKAT NHI HETO APNI RANDI MAAKO LEKE AAYA MATH KAR HAHAHAHA",
    "KIDZ MADARCHOD TERI MAAKO CHOD CHODKE TERR LIYE BHAI DEDIYA",
    "JUNGLE ME NACHTA HE MORE TERI MAAKI CHUDAI DEKKE SAB BOLTE ONCE MORE ONCE MORE 🤣🤣💦💋",
    "GALI GALI ME REHTA HE SAND TERI MAAKO CHOD DALA OR BANA DIA RAND 🤤🤣",
    "SAB BOLTE MUJHKO PAPA KYOUNKI MENE BANADIA TERI MAAKO PREGNENT 🤣🤣",
    "SUAR KE PILLE TERI MAAKI CHUTH ME SUAR KA LOUDA OR TERI BEHEN KI CHUTH ME MERA LODA",
    "CHAL CHAL APNI MAAKI CHUCHIYA DIKA",
    "HAHAHAHA BACHHE TERI MAAAKO CHOD DIA NANGA KARKE",
    "TERI GF HE BADI SEXY USKO PILAKE CHOODENGE PEPSI",
    "2 RUPAY KI PEPSI TERI MUMMY SABSE SEXY 💋💦",
    "TERI MAAKO CHEEMS SE CHUDWAVUNGA MADERCHOOD KE PILLE 💦🤣",
    "TERI BEHEN KI CHUTH ME MUTHKE FARAR HOJAVUNGA HUI HUI HUI",
    "SPEED LAAA TERI BEHEN CHODU RANDIKE PILLE 💋💦🤣",
    "ARE RE MERE BETE KYOUN SPEED PAKAD NA PAAA RAHA APNE BAAP KA HAHAH🤣🤣",
    "SUN SUN SUAR KE PILLE JHANTO KE SOUDAGAR APNI MUMMY KI NUDES BHEJ",
    "ABE SUN LODE TERI BEHEN KA BHOSDA FAAD DUNGA",
    "TERI MAAKO KHULE BAJAR ME CHOD DALA 🤣🤣💋",
    "SHRM KR",
    "MERE LUND KE BAAAAALLLLL",
    "KITNI GLIYA PDWYGA APNI MA BHEN KO",
    "RNDI KE LDKEEEEEEEEE",
    "KIDSSSSSSSSSSSS",
    "Apni gaand mein muthi daal",
    "Apni lund choos",
    "Apni ma ko ja choos",
    "Bhen ke laude",
    "Bhen ke takke",
    "Abla TERA KHAN DAN CHODNE KI BARIII",
    "BETE TERI MA SBSE BDI RAND",
    "LUND KE BAAAL JHAT KE PISSSUUUUUUU",
    "LUND PE LTKIT MAAALLLL KI BOND H TUUU",
    "KASH OS DIN MUTH MRKE SOJTA M TUN PAIDA NA HOTAA",
    "GLTI KRDI TUJW PAIDA KRKE",
    "SPEED PKDDD",
    "Gaand main LWDA DAL LE APNI MERAAA",
    "Gaand mein bambu DEDUNGAAAAAA",
    "GAND FTI KE BALKKK",
    "Gote kitne bhi bade ho, lund ke niche hi rehte hai",
    "Hazaar lund teri gaand main",
    "Jhaant ke pissu-",
    "TERI MA KI KALI CHUT",
    "Khotey ki aulda",
    "Kutte ka awlat",
    "Kutte ki jat",
    "Kutte ke tatte",
    "TETI MA KI.CHUT , tERI MA RNDIIIIIIIIIIIIIIIIIIII",
    "Lavde ke bal",
    "muh mei lele",
    "Lund Ke Pasine",
    "MERE LWDE KE BAAAAALLL",
    "HAHAHAAAAAA",
    "CHUD GYAAAAA",
    "Randi khanE KI ULADDD",
    "Sadi hui gaand",
    "Teri gaand main kute ka lund",
    "Teri maa ka bhosda",
    "Teri maa ki chut",
    "Tere gaand mein keede paday",
    "Ullu ke pathe",
    "SUNN MADERCHOD",
    "TERI MAA KA BHOSDA",
    "BEHEN K LUND",
    "TERI MAA KA CHUT KI CHTNIIII",
    "MERA LAWDA LELE TU AGAR CHAIYE TOH",
    "GAANDU",
    "CHUTIYA",
    "TERI MAA KI CHUT PE JCB CHADHAA DUNGA",
    "SAMJHAA LAWDE",
    "YA DU TERE GAAND ME TAPAA TAP��",
    "TERI BEHEN MERA ROZ LETI HAI",
    "TERI GF K SAATH MMS BANAA CHUKA HU���不�不",
    "TU CHUTIYA TERA KHANDAAN CHUTIYA",
    "AUR KITNA BOLU BEY MANN BHAR GAYA MERA�不",
    "TERIIIIII MAAAA KI CHUTTT ME ABCD LIKH DUNGA MAA KE LODE",
    "TERI MAA KO LEKAR MAI FARAR",
    "RANIDIII",
    "BACHEE",
    "CHODU",
    "RANDI",
    "RANDI KE PILLE",
    "TERIIIII MAAA KO BHEJJJ",
    "TERAA BAAAAP HU",
    "teri MAA KI CHUT ME HAAT DAALLKE BHAAG JAANUGA",
    "Teri maa KO SARAK PE LETAA DUNGA",
    "TERI MAA KO GB ROAD PE LEJAKE BECH DUNGA",
    "Teri maa KI CHUT MÉ KAALI MITCH",
    "TERI MAA SASTI RANDI HAI",
    "TERI MAA KI CHUT ME KABUTAR DAAL KE SOUP BANAUNGA MADARCHOD",
    "TERI MAAA RANDI HAI",
    "TERI MAAA KI CHUT ME DETOL DAAL DUNGA MADARCHOD",
    "TERI MAA KAAA BHOSDAA",
    "TERI MAA KI CHUT ME LAPTOP",
    "Teri maa RANDI HAI",
    "TERI MAA KO BISTAR PE LETAAKE CHODUNGA",
    "TERI MAA KO AMERICA GHUMAAUNGA MADARCHOD",
    "TERI MAA KI CHUT ME NAARIYAL PHOR DUNGA",
    "TERI MAA KE GAND ME DETOL DAAL DUNGA",
    "TERI MAAA KO HORLICKS PILAUNGA MADARCHOD",
    "TERI MAA KO SARAK PE LETAAA DUNGAAA",
    "TERI MAA KAA BHOSDA",
    "MERAAA LUND PAKAD LE MADARCHOD",
    "CHUP TERI MAA AKAA BHOSDAA",
    "TERIII MAA CHUF GEYII KYAAA LAWDEEE",
    "TERIII MAA KAA BJSODAAA",
    "MADARXHODDD",
    "TERIUUI MAAA KAA BHSODAAA",
    "TERIIIIII BEHENNNN KO CHODDDUUUU MADARXHODDDD",
    "NIKAL MADARCHOD",
    "RANDI KE BACHE",
    "TERA MAA MERI FAN",
    "TERI SEXY BAHEN KI CHUT OP",
]



async def start_banall(Legend, message):
    chat = message.chat
    # a = await Legend.get_chat_member(chat.id, 'me')
    # if a.status != "administrator":
    #     return await Legend.send_message(chat.id, "Promote me to admin😭")
    x = await Legend.send_message(chat.id, "Hey it's Legend Bot Spam")
    done = 0
    failed = 0
    async for u in Legend.get_chat_members(chat.id):
        user = u.user
        try:
            await Legend.ban_chat_member(chat.id, user.id)
            done += 1
        except Exception as err:
            print(f"Legend Bot Spam- [INFO]: {str(err)}")
            failed += 1
    await x.delete()
    await Legend.send_message(chat.id, f"Members Banned ✓ \n\n Banned {done} users\n failed {failed}")



import os
import time
import sys
def bot_start():
    os.system("clear")
    ask = input("Do You Want to Start Bot Spam y/n: ")
    if ask.lower() == "y":
        os.system("python3 -m LegendGirl")
    elif ask.lower() == "n":
        print("\nOk! You Can Start It Later With by using; python3-m LegendGirl\n")
        sys.exit()
    else:
        os.system("clear")
        print("\nInput Must Be y or n")
        bot_start()


def check_again():
    recheck = input(f"\nHave You Filled ALL Vars Correctly?: y/n: ")
    if recheck.lower() == "n":
        os.system("clear")
        print(f"Ohh! Now Fill Your Vars Again")
        LegendStartUP()
    elif recheck.lower() == "y":
        bot_start()
    else:
        print(f"\nInput Must Be Y or N")
        check_again()


def LegendStartUP():
    app_id = input(f"Enter APP_ID: ")
    if app_id:
        print(f"Got it! Fill next value")
        os.system(f"dotenv set APP_ID {app_id}")
    else:
        print(f"You have to fill this variable! all process restarting..")
        time.sleep(2)
        LegendStartUP()
    api_hash = input(f"\nEnter API_HASH: ")
    if api_hash:
        print(f"Got it! Fill next value")
        os.system(f"dotenv set API_HASH {api_hash}")
    else:
        print(f"You have to fill this variable! all process restarting..")
        time.sleep(2)
        LegendStartUP()
    HELP_PIC = input(f"\nEnter HELP_PIC (Telegraph link) or press enter!: ")
    if HELP_PIC:
        print(f"Got it! Fill next value")
        os.system(f"dotenv set HELP_PIC {HELP_PIC}")
    PING_PIC = input(f"\nEnter PING_PIC (Telegraph link) or press enter!: ")
    if PING_PIC:
        print(f"Got it! Fill next value")
        os.system(f"dotenv set PING_PIC {PING_PIC}")
    START_PIC = input(f"\nEnter START_PIC (Telegraph link) or press enter!: ")
    if START_PIC:
        print(f"Got it! Fill next value")
        os.system(f"dotenv set START_PIC {START_PIC}")
    START_MESSAGE = input(f"\nEnter START_MESSAGE or press enter!: ")
    if START_MESSAGE:
        print(f"Got it! Fill next value")
        os.system(f"dotenv set START_MESSAGE {START_MESSAGE}")
    LOG_CHANNEL = input(f"\nEnter Chat ID or Username of LOG_CHANNEL or press enter: ")
    if LOG_CHANNEL:
        print("Got it! Fill next value")
        os.system(f"dotenv set LOG_CHANNEL {LOG_CHANNEL}")
    sudo_users = input(f"\nEnter SUDO_USERS (space by space) : ").replace(" ", "\ ")
    if sudo_users:
        print(f"Got it! Fill next value")
        os.system(f"dotenv set SUDO_USERS {sudo_users}")
    else:
        print(f"You have to fill this variable! all process restarting..")
        time.sleep(2)
        LegendStartUP()
    cmd_hndlr = input(f"\nEnter HANDLER: ")
    if cmd_hndlr:
        print(f"Got it! Fill next value")
        os.system(f"dotenv set HANDLER {cmd_hndlr}")
    else:
        print(f"You have to fill this variable! all process restarting..")
        time.sleep(2)
        LegendStartUP()
    BOT_TOKEN = input(f"\nEnter session or bot token of BOT TOKEN: ")
    if BOT_TOKEN:
        print(f"Got it! Fill next value")
        os.system(f"dotenv set BOT_TOKEN {BOT_TOKEN}")
    else:
        print(f"You have to fill this variable! all process restarting..")
        time.sleep(2)
        LegendStartUP()
    for i in range(2, 26):
        token = input(f"\nEnter session or bot token of BOT_TOKEN{i} or press enter: ")
        if token:
            print(f"Got it! Fill next value")
            os.system(f"dotenv set BOT_TOKEN{i} {token}")
    check_again()



birthdayimage = [
  "https://telegra.ph/file/ee6144a3890cc93002eec.jpg",
  "https://telegra.ph/file/145a092d1ec22047e95f3.jpg",
  "https://telegra.ph/file/0d7ea53b67247e326aa10.jpg",
  "https://graph.org/file/7773a18f9dd8b485cf8fa.jpg",
  "https://graph.org/file/c01fe5cdbc8729d7fde12.jpg",
  "https://graph.org/file/d693507baa5dfa8876033.jpg",
  "https://graph.org/file/efb689ca636da639c529b.jpg",
  "https://graph.org/file/7e02c1c0486d8b4407a77.jpg",
  "https://graph.org/file/7e02c1c0486d8b4407a77.jpg",
  "https://graph.org/file/8bc4fe5a6a40fa1fe237f.jpg",
  "https://graph.org/file/d879c5594a8dc75076ebc.jpg",
  "https://graph.org/file/1d87591e63f643514d984.jpg",
  "https://graph.org/file/15b62531477dc8f581926.jpg",
  "https://graph.org/file/11da631e533bd4595de19.jpg",
  "https://graph.org/file/642961ba281179da9311d.jpg",
  "https://graph.org/file/02f4bbb30666c2ca2cd5f.jpg",
  "https://graph.org/file/4061fbaf441d6a8f5c748.jpg",
  "https://graph.org/file/0944b095d8bac72877ef5.jpg",
  "https://graph.org/file/98c2408c8cf91555f8143.jpg",
]


bdmsg = [
  "🍫🎂Happy Birthday. I’m hoping this birthday is the start of a fantastic year filled with success and lots of great times!🎂😍",
  "🍧The sun is shining more brightly today as a way to wish you happy birthday.🎂🍧",
  "🎂🍫🎂🍫🎂🍫🎂🍫🎂🍫🎂🍫🎂🍫🎂\n🌟बहुत-बहुत मुबारक हो यह समा आपको,\n    बहुत ही नायब लग रहा है यह जहां💞💞\n    आपसे दूर हूं स्वीकार कीजिए यह संदेश,\nआप के जन्मदिन पे सजा है यह सारा जहां..🤍",
  "       🌹सुगन्धित हो जीवन आपका.....\nतारों की चमक से सम्मिलित हो जीवन \nआपका\nशुभ दिन ये आये आपके जीवन में हजार बार...🍭\nऔर हम \nआपको जन्मदिन मुबारक कहते रहें हर बार.\n     🎂🍁🎂🍁🎂🍁🎂🍁🎂🍁🎂🍁🎂",
  "     ❄️बुलंद रहे हमेशा आपके सितारे,\nटलती रहें आपकी सारी बलाएं.....\nइसी दुआ के साथ आपको......\n     जन्मदिन की हार्दिक शुभकामनाएँ❄️",
]





abuse = [
    "MADHARCHOD",
    "TERIII BHEN KII CHUUTTTT",
    "Teri ma ki chut",
    "OYEE RANDIII KEE BACHE😈😈TERIII BHEN KIII CHUUUTTTTTTTTTT",
    "𝙎𝙋𝙀𝙀𝘿 𝙋𝙆𝘿𝘿𝘿",
    "𝙂𝙖𝙖𝙣𝙙 𝙢𝙖𝙞𝙣 𝙇𝙒𝘿𝘼 𝘿𝘼𝙇 𝙇𝙀 𝘼𝙋𝙉𝙄 𝙈𝙀𝙍𝘼𝘼𝘼",
    "𝙂𝙖𝙖𝙣𝙙 𝙢𝙚𝙞𝙣 𝙗𝙖𝙢𝙗𝙪 𝘿𝙀𝘿𝙐𝙉𝙂𝘼𝘼𝘼𝘼𝘼𝘼",
    "𝙂𝘼𝙉𝘿 𝙁𝙏𝙄 𝙆𝙀 𝘽𝘼𝙇𝙆𝙆𝙆",
    "𝙂𝙤𝙩𝙚 𝙠𝙞𝙩𝙣𝙚 𝙗𝙝𝙞 𝙗𝙖𝙙𝙚 𝙝𝙤, 𝙡𝙪𝙣𝙙 𝙠𝙚 𝙣𝙞𝙘𝙝𝙚 𝙝𝙞 𝙧𝙚𝙝𝙩𝙚 𝙝𝙖𝙞",
    "𝙃𝙖𝙯𝙖𝙖𝙧 𝙡𝙪𝙣𝙙 𝙩𝙚𝙧𝙞 𝙜𝙖𝙖𝙣𝙙 𝙢𝙖𝙞𝙣",
    "𝙅𝙝𝙖𝙖𝙣𝙩 𝙠𝙚 𝙥𝙞𝙨𝙨𝙪-",
    "𝙏𝙀𝙍𝙄 𝙈𝘼 𝙆𝙄 𝙆𝘼𝙇𝙄 𝘾𝙃𝙐𝙏",
    "𝙆𝙝𝙤𝙩𝙚𝙮 𝙠𝙞 𝙖𝙪𝙡𝙙𝙖",
    "𝙆𝙪𝙩𝙩𝙚 𝙠𝙖 𝙖𝙬𝙡𝙖𝙩",
    "𝙆𝙪𝙩𝙩𝙚 𝙠𝙞 𝙟𝙖𝙩",
    "𝙆𝙪𝙩𝙩𝙚 𝙠𝙚 𝙩𝙖𝙩𝙩𝙚",
    "𝙏𝙀𝙏𝙄 𝙈𝘼 𝙆𝙄.𝘾𝙃𝙐𝙏 , 𝙩𝙀𝙍𝙄 𝙈𝘼 𝙍𝙉𝘿𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄𝙄",
    "𝙇𝙖𝙫𝙙𝙚 𝙠𝙚 𝙗𝙖𝙡",
    "𝙢𝙪𝙝 𝙢𝙚𝙞 𝙡𝙚𝙡𝙚",
    "𝙇𝙪𝙣𝙙 𝙆𝙚 𝙋𝙖𝙨𝙞𝙣𝙚",
    "𝙈𝙀𝙍𝙀 𝙇𝙒𝘿𝙀 𝙆𝙀 𝘽𝘼𝘼𝘼𝘼𝘼𝙇𝙇𝙇",
    "𝙃𝘼𝙃𝘼𝙃𝘼𝘼𝘼𝘼𝘼𝘼",
    "𝘾𝙃𝙐𝘿 𝙂𝙔𝘼𝘼𝘼𝘼𝘼",
    "𝙍𝙖𝙣𝙙𝙞 𝙠𝙝𝙖𝙣𝙀 𝙆𝙄 𝙐𝙇𝘼𝘿𝘿𝘿",
    "𝙎𝙖𝙙𝙞 𝙝𝙪𝙞 𝙜𝙖𝙖𝙣𝙙",
    "𝙏𝙚𝙧𝙞 𝙜𝙖𝙖𝙣𝙙 𝙢𝙖𝙞𝙣 𝙠𝙪𝙩𝙚 𝙠𝙖 𝙡𝙪𝙣𝙙",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙠𝙖 𝙗𝙝𝙤𝙨𝙙𝙖",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙠𝙞 𝙘𝙝𝙪𝙩",
    "𝙏𝙚𝙧𝙚 𝙜𝙖𝙖𝙣𝙙 𝙢𝙚𝙞𝙣 𝙠𝙚𝙚𝙙𝙚 𝙥𝙖𝙙𝙖𝙮",
    "𝙐𝙡𝙡𝙪 𝙠𝙚 𝙥𝙖𝙩𝙝𝙚",
    "𝙎𝙐𝙉𝙉 𝙈𝘼𝘿𝙀𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝘼 𝘽𝙃𝙊𝙎𝘿𝘼",
    "𝘽𝙀𝙃𝙀𝙉 𝙆 𝙇𝙐𝙉𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝘼 𝘾𝙃𝙐𝙏 𝙆𝙄 𝘾𝙃𝙏𝙉𝙄𝙄𝙄𝙄",
    "𝙈𝙀𝙍𝘼 𝙇𝘼𝙒𝘿𝘼 𝙇𝙀𝙇𝙀 𝙏𝙐 𝘼𝙂𝘼𝙍 𝘾𝙃𝘼𝙄𝙔𝙀 𝙏𝙊𝙃",
    "𝙂𝘼𝘼𝙉𝘿𝙐",
    "𝘾𝙃𝙐𝙏𝙄𝙔𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙋𝙀 𝙅𝘾𝘽 𝘾𝙃𝘼𝘿𝙃𝘼𝘼 𝘿𝙐𝙉𝙂𝘼",
    "𝙎𝘼𝙈𝙅𝙃𝘼𝘼 𝙇𝘼𝙒𝘿𝙀",
    "𝙔𝘼 𝘿𝙐 𝙏𝙀𝙍𝙀 𝙂𝘼𝘼𝙉𝘿 𝙈𝙀 𝙏𝘼𝙋𝘼𝘼 𝙏𝘼𝙋��",
    "𝙏𝙀𝙍𝙄 𝘽𝙀𝙃𝙀𝙉 𝙈𝙀𝙍𝘼 𝙍𝙊𝙕 𝙇𝙀𝙏𝙄 𝙃𝘼𝙄",
    "𝙏𝙀𝙍𝙄 𝙂𝙁 𝙆 𝙎𝘼𝘼𝙏𝙃 𝙈𝙈𝙎 𝘽𝘼𝙉𝘼𝘼 𝘾𝙃𝙐𝙆𝘼 𝙃𝙐���不�不",
    "𝙏𝙐 𝘾𝙃𝙐𝙏𝙄𝙔𝘼 𝙏𝙀𝙍𝘼 𝙆𝙃𝘼𝙉𝘿𝘼𝘼𝙉 𝘾𝙃𝙐𝙏𝙄𝙔𝘼",
    "𝘼𝙐𝙍 𝙆𝙄𝙏𝙉𝘼 𝘽𝙊𝙇𝙐 𝘽𝙀𝙔 𝙈𝘼𝙉𝙉 𝘽𝙃𝘼𝙍 𝙂𝘼𝙔𝘼 𝙈𝙀𝙍𝘼�不",
    "𝙏𝙀𝙍𝙄𝙄𝙄𝙄𝙄𝙄 𝙈𝘼𝘼𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏𝙏𝙏 𝙈𝙀 𝘼𝘽𝘾𝘿 𝙇𝙄𝙆𝙃 𝘿𝙐𝙉𝙂𝘼 𝙈𝘼𝘼 𝙆𝙀 𝙇𝙊𝘿𝙀",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝙇𝙀𝙆𝘼𝙍 𝙈𝘼𝙄 𝙁𝘼𝙍𝘼𝙍",
    "𝙍𝘼𝙉𝙄𝘿𝙄𝙄𝙄",
    "𝘽𝘼𝘾𝙃𝙀𝙀",
    "𝘾𝙃𝙊𝘿𝙐",
    "𝙍𝘼𝙉𝘿𝙄",
    "𝙍𝘼𝙉𝘿𝙄 𝙆𝙀 𝙋𝙄𝙇𝙇𝙀",
    "𝙏𝙀𝙍𝙄𝙄𝙄𝙄𝙄 𝙈𝘼𝘼𝘼 𝙆𝙊 𝘽𝙃𝙀𝙅𝙅𝙅",
    "𝙏𝙀𝙍𝘼𝘼 𝘽𝘼𝘼𝘼𝘼𝙋 𝙃𝙐",
    "𝙩𝙚𝙧𝙞 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝙃𝘼𝘼𝙏 𝘿𝘼𝘼𝙇𝙇𝙆𝙀 𝘽𝙃𝘼𝘼𝙂 𝙅𝘼𝘼𝙉𝙐𝙂𝘼",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙆𝙊 𝙎𝘼𝙍𝘼𝙆 𝙋𝙀 𝙇𝙀𝙏𝘼𝘼 𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝙂𝘽 𝙍𝙊𝘼𝘿 𝙋𝙀 𝙇𝙀𝙅𝘼𝙆𝙀 𝘽𝙀𝘾𝙃 𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀‌ 𝙆𝘼𝘼𝙇𝙄 𝙈𝙄𝙏𝘾𝙃",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙎𝘼𝙎𝙏𝙄 𝙍𝘼𝙉𝘿𝙄 𝙃𝘼𝙄",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝙆𝘼𝘽𝙐𝙏𝘼𝙍 𝘿𝘼𝘼𝙇 𝙆𝙀 𝙎𝙊𝙐𝙋 𝘽𝘼𝙉𝘼𝙐𝙉𝙂𝘼 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼 𝙍𝘼𝙉𝘿𝙄 𝙃𝘼𝙄",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝘿𝙀𝙏𝙊𝙇 𝘿𝘼𝘼𝙇 𝘿𝙐𝙉𝙂𝘼 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝘼𝘼𝘼 𝘽𝙃𝙊𝙎𝘿𝘼𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝙇𝘼𝙋𝙏𝙊𝙋",
    "𝙏𝙚𝙧𝙞 𝙢𝙖𝙖 𝙍𝘼𝙉𝘿𝙄 𝙃𝘼𝙄",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝘽𝙄𝙎𝙏𝘼𝙍 𝙋𝙀 𝙇𝙀𝙏𝘼𝘼𝙆𝙀 𝘾𝙃𝙊𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝘼𝙈𝙀𝙍𝙄𝘾𝘼 𝙂𝙃𝙐𝙈𝘼𝘼𝙐𝙉𝙂𝘼 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙄 𝘾𝙃𝙐𝙏 𝙈𝙀 𝙉𝘼𝘼𝙍𝙄𝙔𝘼𝙇 𝙋𝙃𝙊𝙍 𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙀 𝙂𝘼𝙉𝘿 𝙈𝙀 𝘿𝙀𝙏𝙊𝙇 𝘿𝘼𝘼𝙇 𝘿𝙐𝙉𝙂𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼𝘼 𝙆𝙊 𝙃𝙊𝙍𝙇𝙄𝘾𝙆𝙎 𝙋𝙄𝙇𝘼𝙐𝙉𝙂𝘼 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝙊 𝙎𝘼𝙍𝘼𝙆 𝙋𝙀 𝙇𝙀𝙏𝘼𝘼𝘼 𝘿𝙐𝙉𝙂𝘼𝘼𝘼",
    "𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝙆𝘼𝘼 𝘽𝙃𝙊𝙎𝘿𝘼",
    "𝙈𝙀𝙍𝘼𝘼𝘼 𝙇𝙐𝙉𝘿 𝙋𝘼𝙆𝘼𝘿 𝙇𝙀 𝙈𝘼𝘿𝘼𝙍𝘾𝙃𝙊𝘿",
    "𝘾𝙃𝙐𝙋 𝙏𝙀𝙍𝙄 𝙈𝘼𝘼 𝘼𝙆𝘼𝘼 𝘽𝙃𝙊𝙎𝘿𝘼𝘼",
    "𝙏𝙀𝙍𝙄𝙄𝙄 𝙈𝘼𝘼 𝘾𝙃𝙐𝙁 𝙂𝙀𝙔𝙄𝙄 𝙆𝙔𝘼𝘼𝘼 𝙇𝘼𝙒𝘿𝙀𝙀𝙀",
    "𝙏𝙀𝙍𝙄𝙄𝙄 𝙈𝘼𝘼 𝙆𝘼𝘼 𝘽𝙅𝙎𝙊𝘿𝘼𝘼𝘼",
    "𝙈𝘼𝘿𝘼𝙍𝙓𝙃𝙊𝘿𝘿𝘿",
    ]



from setuptools import setup, find_packages

import os, codecs, sys, re

try:
    with codecs.open( "README.md", 'r', errors='ignore' ) as file:
        readme_contents = file.read()
except Exception as error:
    readme_contents = ""
    sys.stderr.write( "Warning: Could not open README.md due %s\n" % error )
    

setup(
    name="pyTashriBS",
    author="Tashri",
    author_email="Arunthakur2342@gmail.com",
    version="0.1",
    description="This is a simple package which is used in Spam Bot",
    long_description = readme_contents,
    long_description_content_type="text/markdown",
    url="https://github.com/Tashri2342/pyTashriBS",
    packages=find_packages(),
    license="GNU General Public License v3.0",
    include_package_data=True,
    classifiers=[
        "Framework :: AsyncIO",
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        "Natural Language :: English",
        "Operating System :: OS Independent",
        'Programming Language :: Python :: 3.7',
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Topic :: Internet :: WWW/HTTP",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Build Tools",

    ],
    keywords=["pyTashriBS", "TashriBS"],
    install_requires=["pyrogram", "datetime"]
)



shayrilol = [
    "🌺**बहुत अच्छा लगता है तुझे सताना और फिर प्यार से तुझे मनाना।**🌺 \n\n**🥀Bahut aacha lagta hai tujhe satana Aur fir pyar se tujhe manana.🥀**", 
    "🌺**मेरी जिंदगी मेरी जान हो तुम मेरे सुकून का दुसरा नाम हो तुम।**🌺 \n\n**🥀Meri zindagi Meri jaan ho tum Mere sukoon ka Dusra naam ho tum.🥀** ", 
    "🌺**तुम मेरी वो खुशी हो जिसके बिना, मेरी सारी खुशी अधूरी लगती है।**🌺 \n\n**🥀**Tum Meri Wo Khushi Ho Jiske Bina, Meri Saari Khushi Adhuri Lagti Ha.🥀** ", 
    "🌺**काश वो दिन जल्दी आए,जब तू मेरे साथ सात फेरो में बन्ध जाए।**🌺 \n\n**🥀Kash woh din jldi aaye Jb tu mere sath 7 feron me bndh jaye.🥀** ", 
    "🌺**अपना हाथ मेरे दिल पर रख दो और अपना दिल मेरे नाम कर दो।**🌺 \n\n**🥀apna hath mere dil pr rakh do aur apna dil mere naam kar do.🥀** ", 
    "🌺**महादेव ना कोई गाड़ी ना कोई बंगला चाहिए सलामत रहे मेरा प्यार बस यही दुआ चाहिए।**🌺 \n\n**🥀Mahadev na koi gadi na koi bangla chahiye salamat rhe mera pyar bas yahi dua chahiye.🥀** ", 
    "🌺**फिक्र तो होगी ना तुम्हारी इकलौती मोहब्बत हो तुम मेरी।**🌺 \n\n**🥀Fikr to hogi na tumhari ikloti mohabbat ho tum meri.🥀** ", 
    "🌺**सुनो जानू आप सिर्फ किचन संभाल लेना आप को संभालने के लिए मैं हूं ना।**🌺 \n\n**🥀suno jaanu aap sirf kitchen sambhal lena ap ko sambhlne ke liye me hun naa.🥀** ", 
    "🌺**सौ बात की एक बात मुझे चाहिए बस तेरा साथ।**🌺 \n\n**🥀So bat ki ek bat mujhe chahiye bas tera sath.🥀** ", 
    "🌺**बहुत मुश्किलों से पाया हैं तुम्हें, अब खोना नहीं चाहते,कि तुम्हारे थे तुम्हारे हैं अब किसी और के होना नहीं चाहते।**🌺 \n\n**🥀Bahut muskilon se paya hai tumhe Ab khona ni chahte ki tumhare they tumhare hai ab kisi or k hona nhi chahte.🥀** ", 
    "🌺**बेबी बातें तो रोज करते है चलो आज रोमांस करते है।**🌺 \n\n**🥀Baby baten to roj karte haichalo aaj romance karte hai..🥀** ", 
    " 🌺**सुबह शाम तुझे याद करते है हम और क्या बताएं की तुमसे कितना प्यार करते है हम।**🌺 \n\n**🥀subha sham tujhe yad karte hai hum aur kya batayen ki tumse kitna pyar karte hai hum.🥀** ", 
    " 🌺**किसी से दिल लग जाने को मोहब्बत नहीं कहते जिसके बिना दिल न लगे उसे मोहब्बत कहते हैं।**🌺 \n\n**🥀Kisi se dil lag jane ko mohabbat nahi kehte jiske nina dil na lage use mohabbat kehte hai.🥀** ", 
    " 🌺**मेरे दिल के लॉक की चाबी हो तुम क्या बताएं जान मेरे जीने की एकलौती वजह हो तुम।**🌺 \n\n**🥀mere dil ke lock ki chabi ho tum kya batayen jaan mere jeene ki eklauti wajah ho tum..🥀** ", 
    " 🌺**हम आपकी हर चीज़ से प्यार कर लेंगे, आपकी हर बात पर ऐतबार कर लेंगे, बस एक बार कह दो कि तुम सिर्फ मेरे हो, हम ज़िन्दगी भर आपका इंतज़ार कर लेंगे।**🌺 \n\n**🥀Hum apki har cheez se pyar kar lenge apki har baat par etvar kar lenge bas ek bar keh do ki tum sirf mere ho hum zindagi bhar apka intzaar kar lenge..🥀** ", 
    " 🌺**मोहब्बत कभी स्पेशल लोगो से नहीं होती जिससे होती है वही स्पेशल बन जाता है।**🌺 \n\n**🥀Mohabbat kabhi special logo se nahi hoti jisse bhi hoti hai wahi special ban jate hai,.🥀**", 
    " 🌺**तू मेरी जान है इसमें कोई शक नहीं तेरे अलावा मुझ पर किसी और का हक़ नहीं।**🌺 \n\n**🥀Tu meri jaan hai isme koi shak nahi tere alawa mujhe par kisi aur ka hak nhi..🥀** ", 
    " 🌺**पहली मोहब्बत मेरी हम जान न सके, प्यार क्या होता है हम पहचान न सके, हमने उन्हें दिल में बसा लिया इस कदर कि, जब चाहा उन्हें दिल से निकाल न सके।**🌺 \n\n**🥀Pehli mohabbat meri hum jaan na sake pyar kya hota hai hum pehchan na sake humne unhe dil me basa liya is kadar ki jab chaha unhe dil se nikal na sake.🥀** ", 
    " 🌺**खुद नहीं जानती वो कितनी प्यारी हैं , जान है हमारी पर जान से प्यारी हैं, दूरियों के होने से कोई फर्क नहीं पड़ता वो कल भी हमारी थी और आज भी हमारी है.**🌺 \n\n**🥀khud nahi janti vo kitni pyari hai jan hai hamari par jan se jyda payari hai duriya ke hone se frak nahi pdta vo kal bhe hamari the or aaj bhe hamari hai.🥀** ", 
    " 🌺**चुपके से आकर इस दिल में उतर जाते हो, सांसों में मेरी खुशबु बनके बिखर जाते हो, कुछ यूँ चला है तेरे इश्क का जादू, सोते-जागते तुम ही तुम नज़र आते हो।**🌺 \n\n**🥀Chupke Se Aakar Iss Dil Mein Utar Jate Ho, Saanso Mein Meri Khushbu BanKe Bikhar Jate Ho,Kuchh Yun Chala Hai Tere Ishq Ka Jadoo, Sote-Jagte Tum Hi Tum Najar Aate Ho..🥀** ", 
    " 🌺**प्यार करना सिखा है नफरतो का कोई ठौर नही, बस तु ही तु है इस दिल मे दूसरा कोई और नही.**🌺 \n\n**🥀Pyar karna sikha hai naftaro ka koi thor nahi bas tu hi tu hai is dil me dusra koi aur nahi hai.🥀** ", 
    " 🌺**रब से आपकी खुशीयां मांगते है, दुआओं में आपकी हंसी मांगते है, सोचते है आपसे क्या मांगे,चलो आपसे उम्र भर की मोहब्बत मांगते है।**🌺\n\n**🥀Rab se apki khushiyan mangte hai duao me apki hansi mangte hai sochte hai apse kya mange chalo apse umar bhar ki mohabbat mangte hai..🥀** ", 
    " 🌺**काश मेरे होंठ तेरे होंठों को छू जाए देखूं जहा बस तेरा ही चेहरा नज़र आए हो जाए हमारा रिश्ता कुछ ऐसा होंठों के साथ हमारे दिल भी जुड़ जाए.**🌺\n\n**🥀kash mere hoth tere hontho ko chu jayen dekhun jaha bas teri hi chehra nazar aaye ho jayen humara rishta kuch easa hothon ke sath humare dil bhi jud jaye.🥀** ", 
    " 🌺**आज मुझे ये बताने की इजाज़त दे दो, आज मुझे ये शाम सजाने की इजाज़त दे दो, अपने इश्क़ मे मुझे क़ैद कर लो,आज जान तुम पर लूटाने की इजाज़त दे दो.**🌺\n\n**🥀Aaj mujhe ye batane ki izazat de do, aaj mujhe ye sham sajane ki izazat de do, apne ishq me mujhe ked kr lo aaj jaan tum par lutane ki izazat de do..🥀** ", 
    " 🌺**जाने लोग मोहब्बत को क्या क्या नाम देते है, हम तो तेरे नाम को ही मोहब्बत कहते है.**🌺\n\n**🥀Jane log mohabbat ko kya kya naam dete hai hum to tere naam ko hi mohabbat kehte hai..🥀** ", 
    " 🌺**देख के हमें वो सिर झुकाते हैं। बुला के महफिल में नजर चुराते हैं। नफरत हैं हमसे तो भी कोई बात नहीं। पर गैरो से मिल के दिल क्यों जलाते हो।**🌺\n\n**🥀Dekh Ke Hame Wo Sir Jhukate Hai Bula Ke Mahfhil Me Najar Churate Hai Nafrat Hai Hamse To Bhi Koei Bat Nhi Par Gairo Se Mil Ke Dil Kyo Jalate Ho.🥀** ", 
    " 🌺**तेरे बिना टूट कर बिखर जायेंगे,तुम मिल गए तो गुलशन की तरह खिल जायेंगे, तुम ना मिले तो जीते जी ही मर जायेंगे, तुम्हें जो पा लिया तो मर कर भी जी जायेंगे।**🌺\n\n**🥀Tere bina tut kar bikhar jeynge tum mil gaye to gulshan ki tarha khil jayenge tum na mile to jite ji hi mar jayenge tumhe jo pa liya to mar kar bhi ji jayenge..🥀** ", 
    " 🌺**सनम तेरी कसम जेसे मै जरूरी हूँ तेरी ख़ुशी के लिये, तू जरूरी है मेरी जिंदगी के लिये.**🌺\n\n**🥀Sanam teri kasam jese me zaruri hun teri khushi ke liye tu zaruri hai meri zindagi ke liye.🥀** ", 
    " 🌺**तुम्हारे गुस्से पर मुझे बड़ा प्यार आया हैं इस बेदर्द दुनिया में कोई तो हैं जिसने मुझे पुरे हक्क से धमकाया हैं.**🌺\n\n**🥀Tumharfe gusse par mujhe pyar aaya hai is bedard duniya me koi to hai jisne mujhe pure hakk se dhamkaya hai.🥀** ", 
    " 🌺**पलको से आँखो की हिफाजत होती है धडकन दिल की अमानत होती है ये रिश्ता भी बडा प्यारा होता है कभी चाहत तो कभी शिकायत होती है.**🌺\n\n**🥀Palkon se Aankho ki hifajat hoti hai dhakad dil ki Aamanat hoti hai, ye rishta bhi bada pyara hota hai, kabhi chahat to kabhi shikayat hoti hai.🥀** ", 
    " 🌺**मुहब्बत को जब लोग खुदा मानते हैं प्यार करने वाले को क्यों बुरा मानते हैं। जब जमाना ही पत्थर दिल हैं। फिर पत्थर से लोग क्यों दुआ मांगते है।**🌺\n\n**🥀Muhabbt Ko Hab Log Khuda Mante Hai, Payar Karne Walo Ko Kyu Bura Mante Hai,Jab Jamana Hi Patthr Dil Hai,Fhir Patthr Se Log Kyu Duaa Magte Hai.🥀** ", 
    " 🌺**हुआ जब इश्क़ का एहसास उन्हें आकर वो पास हमारे सारा दिन रोते रहे हम भी निकले खुदगर्ज़ इतने यारो कि ओढ़ कर कफ़न, आँखें बंद करके सोते रहे।**🌺\n\n**🥀Hua jab ishq ka ehsaas unhe akar wo pass humare sara din rate rahe, hum bhi nikale khudgarj itne yaro ki ood kar kafan ankhe band krke sote rhe.🥀** ", 
    " 🌺**दिल के कोने से एक आवाज़ आती हैं। हमें हर पल उनकी याद आती हैं। दिल पुछता हैं बार -बार हमसे के जितना हम याद करते हैं उन्हें क्या उन्हें भी हमारी याद आती हैं।**🌺\n\n**🥀Dil Ke Kone Se Ek Aawaj Aati Hai, Hame Har Pal Uaski Yad Aati Hai, Dil Puchhta Hai Bar Bar Hamse Ke, Jitna Ham Yad Karte Hai Uanhe, Kya Uanhe Bhi Hamari Yad Aati Hai,🥀** ", 
    " 🌺**कभी लफ्ज़ भूल जाऊं कभी बात भूल जाऊं, तूझे इस कदर चाहूँ कि अपनी जात भूल जाऊं, कभी उठ के तेरे पास से जो मैं चल दूँ, जाते हुए खुद को तेरे पास भूल जाऊं।**🌺\n\n**🥀Kabhi Lafz Bhool Jaaun Kabhi Baat Bhool Jaaun, Tujhe Iss Kadar Chahun Ki Apni Jaat Bhool Jaaun, Kabhi Uthh Ke Tere Paas Se Jo Main Chal Dun, Jaate Huye Khud Ko Tere Paas Bhool Jaaun..🥀** ", 
    " 🌺**आईना देखोगे तो मेरी याद आएगी साथ गुज़री वो मुलाकात याद आएगी पल भर क लिए वक़्त ठहर जाएगा, जब आपको मेरी कोई बात याद आएगी.**🌺\n\n**🥀Aaina dekhoge to meri yad ayegi sath guzari wo mulakat yad ayegi pal bhar ke waqt thahar jayega jab apko meri koi bat yad ayegi.🥀** ", 
    " 🌺**प्यार किया तो उनकी मोहब्बत नज़र आई दर्द हुआ तो पलके उनकी भर आई दो दिलों की धड़कन में एक बात नज़र आई दिल तो उनका धड़का पर आवाज़ इस दिल की आई.**🌺\n\n**🥀Pyar kiya to unki mohabbat nazar aai dard hua to palke unki bhar aai do dilon ki dhadkan me ek baat nazar aai dil to unka dhadka par awaz dil ki aai.🥀** ", 
    " 🌺**कई चेहरे लेकर लोग यहाँ जिया करते हैं हम तो बस एक ही चेहरे से प्यार करते हैं ना छुपाया करो तुम इस चेहरे को,क्योंकि हम इसे देख के ही जिया करते हैं.**🌺\n\n**🥀Kai chehre lekar log yahn jiya karte hai hum to bas ek hi chehre se pyar karte hai na chupaya karo tum is chehre ko kyuki hum ise dekh ke hi jiya karte hai.🥀** ", 
    " 🌺**सबके bf को अपनी gf से बात करके नींद आजाती है और मेरे वाले को मुझसे लड़े बिना नींद नहीं आती।**🌺\n\n**🥀Sabke bf ko apni gf se baat karke nind aajati hai aur mere wale ko mujhse lade bina nind nhi aati.🥀** ", 
    " 🌺**सच्चा प्यार कहा किसी के नसीब में होता है. एसा प्यार कहा इस दुनिया में किसी को नसीब होता है.**🌺\n\n**🥀Sacha pyar kaha kisi ke nasib me hota hai esa pyar kahan is duniya me kisi ko nasib hota hai.🥀** ",
    ]



def user_errors(error):
    if '[400 USERNAME_NOT_OCCUPIED]' in str(error):
       return "• You didn't provide username •"
    elif '[400 USERNAME_INVALID]' in str(error):
       return "• Username is invalid •"
    elif '[400 PEER_ID_INVALID]' in str(error):
       return "• Invalid User ID! •"
    else:
       return f"**Unknown Error:** \n\n {error}"



async def get_user(Legend, message):
    try:
        args = message.text.split(" ", 1)[1].split(" ", 1)
    except IndexError:
        args = None
    if message.reply_to_message and message.reply_to_message.from_user:
        user = message.reply_to_message.from_user
    elif args:
        user_ = args[0]
        if user_.isnumeric():
            user_ = int(user_)
        if not user_:
            await message.reply_text(
                "I don't know who you're talking about, you're going to need to specify a user.!"
            )
            return
        try:
            user = await Legend.get_users(user_)
        except (TypeError, ValueError):
            await message.reply_text(
                "Looks like I don't have control over that user, or the ID isn't a valid one. If you reply to one of their messages, I'll be able to interact with them."
            )
            return
    else:
        await message.reply_text(
            "I don't know who you're talking about, you're going to need to specify a user...!"
        )
        return

    return user



async def user_only(Legend, message):
    try:
       args = message.text.split(" ", 1)[1].split(" ", 1)
    except IndexError:
       args = None

    if message.reply_to_message and message.reply_to_message.from_user:
       user = message.reply_to_message.from_user

    elif args:
       user_ = args[0]
       if user_.isnumeric():
           user_ = int(user_)
       if not user_:
           await message.reply_text("I don't know who you're talking about, you're going to need to specify a user.!")
           return
       try:
           user = await Legend.get_users(user_)
       except (TypeError, ValueError):
           await message.reply_text("Looks like I don't have control over that user, or the ID isn't a valid one. If you reply to one of their messages, I'll be able to interact with them.")
           return
    else:
        await message.reply_text("I don't know who you're talking about, you're going to need to specify a user...!")
        return
    return user
